=== modified file 'lib/Controller/User.php'
--- lib/Controller/User.php	2016-08-31 10:12:21 +0000
+++ lib/Controller/User.php	2016-09-01 07:41:43 +0000
@@ -27,6 +27,7 @@
 use Xibo\Entity\Region;
 use Xibo\Entity\Widget;
 use Xibo\Exception\AccessDeniedException;
+use Xibo\Exception\ConfigurationException;
 use Xibo\Factory\ApplicationFactory;
 use Xibo\Factory\CampaignFactory;
 use Xibo\Factory\DisplayFactory;
@@ -763,6 +764,8 @@
             'entity' => $requestEntity,
             'objectId' => $objectId,
             'permissions' => $currentPermissions,
+            'canSetOwner' => method_exists($object, 'setOwner'),
+            'owners' => $this->userFactory->query(),
             'help' => [
                 'permissions' => $this->getHelp()->link('Campaign', 'Permissions')
             ]
@@ -801,6 +804,13 @@
      *      required=true,
      *      @SWG\Items(type="string")
      *   ),
+     *  @SWG\Parameter(
+     *      name="ownerId",
+     *      in="formData",
+     *      description="Change the owner of this item. Leave empty to keep the current owner",
+     *      type="integer",
+     *      required=false
+     *   ),
      *  @SWG\Response(
      *      response=204,
      *      description="successful operation"
@@ -809,6 +819,7 @@
      *
      * @param string $entity
      * @param int $objectId
+     * @throws ConfigurationException
      */
     public function permissions($entity, $objectId)
     {
@@ -831,11 +842,27 @@
         // Run the update
         $this->updatePermissions($permissions, $groupIds);
 
+        // Should we update the owner?
+        if ($this->getSanitizer()->getInt('ownerId') != 0) {
+
+            $ownerId = $this->getSanitizer()->getInt('ownerId');
+
+            $this->getLog()->debug('Requesting update to a new Owner - id = ' . $ownerId);
+
+            if (method_exists($object, 'setOwner')) {
+                $object->setOwner($ownerId);
+                $object->save();
+            } else {
+                throw new ConfigurationException(__('Cannot change owner on this Object'));
+            }
+        }
+
         // Cascade permissions
         if ($requestEntity == 'Campaign' && $this->getSanitizer()->getCheckbox('cascade') == 1) {
             /* @var Campaign $object */
             $this->getLog()->debug('Cascade permissions down');
 
+            // Define a function that can be called for each layout we find
             $updatePermissionsOnLayout = function($layout) use ($object, $groupIds) {
 
                 // Regions

=== modified file 'views/user-form-permissions.twig'
--- views/user-form-permissions.twig	2015-11-30 12:47:18 +0000
+++ views/user-form-permissions.twig	2016-09-01 07:41:43 +0000
@@ -25,42 +25,53 @@
 {% block callBack %}permissionsFormOpen{% endblock %}
 
 {% block formHtml %}
-    <div class="row">
-        <div class="col-md-12">
-            <div class="XiboGrid permissionsGrid" id="{{ randomId }}"
-                 data-url="{{ urlFor("user.permissions", {entity: entity, id: objectId}) }}"
-                 data-permissions="{{ permissions|json_encode }}">
-                <div class="permissionsTableFilter">
-                    <form onsubmit="false">
-                        {% set title %}{% trans "Name" %}{% endset %}
-                        {{ inline.input("name", title) }}
-                    </form>
-                </div>
-                <div class="XiboData">
-                    <table id="permissionsTable" class="table table-striped">
-                        <thead>
-                        <tr>
-                            <th>{% trans "Name" %}</th>
-                            <th>{% trans "View" %}</th>
-                            <th>{% trans "Edit" %}</th>
-                            <th>{% trans "Delete" %}</th>
-                        </tr>
-                        </thead>
-                        <tbody>
+    <div class="permissions-form">
+        <div class="row">
+            <div class="col-md-12">
+                <div class="XiboGrid permissionsGrid" id="{{ randomId }}"
+                     data-url="{{ urlFor("user.permissions", {entity: entity, id: objectId}) }}"
+                     data-permissions="{{ permissions|json_encode }}">
+                    <div class="permissionsTableFilter">
+                        <form onsubmit="false">
+                            {% set title %}{% trans "Name" %}{% endset %}
+                            {{ inline.input("name", title) }}
+                        </form>
+                    </div>
+                    <div class="XiboData">
+                        <table id="permissionsTable" class="table table-striped">
+                            <thead>
+                            <tr>
+                                <th>{% trans "Name" %}</th>
+                                <th>{% trans "View" %}</th>
+                                <th>{% trans "Edit" %}</th>
+                                <th>{% trans "Delete" %}</th>
+                            </tr>
+                            </thead>
+                            <tbody>
 
-                        </tbody>
-                    </table>
+                            </tbody>
+                        </table>
+                    </div>
                 </div>
             </div>
         </div>
-    </div>
-    {% if entity == "Campaign" %}
-    <div class="row">
-        <div class="col-md-12">
-            {% set title %}{% trans %}Cascade permissions to all items underneath this one.{% endtrans %}{% endset %}
-            {% set helpText %}{% trans %}For example, if this is a Layout then update the permissions on all Regions, Playlists and Widgets.{% endtrans %}{% endset %}
-            {{ forms.checkbox("cascade", title, 0, helpText) }}
-        </div>
-    </div>
-    {% endif %}
+        {% if entity == "Campaign" %}
+        <div class="row">
+            <div class="col-md-12">
+                {% set title %}{% trans %}Cascade permissions to all items underneath this one.{% endtrans %}{% endset %}
+                {% set helpText %}{% trans %}For example, if this is a Layout then update the permissions on all Regions, Playlists and Widgets.{% endtrans %}{% endset %}
+                {{ forms.checkbox("cascade", title, 0, helpText) }}
+            </div>
+        </div>
+        {% endif %}
+        {% if canSetOwner %}
+        <div class="row">
+            <div class="col-md-12">
+                {% set title %}{% trans %}Owner{% endtrans %}{% endset %}
+                {% set helpText %}{% trans %}Change the Owner of this item. Leave empty to keep the current owner.{% endtrans %}{% endset %}
+                {{ forms.dropdown("ownerId", "single", title, "", [{"userId": null, "userName": ""}]|merge(owners), "userId", "userName", helpText) }}
+            </div>
+        </div>
+        {% endif %}
+    </div>
 {% endblock %}
\ No newline at end of file

=== modified file 'web/theme/default/js/xibo-forms.js'
--- web/theme/default/js/xibo-forms.js	2016-06-24 10:56:05 +0000
+++ web/theme/default/js/xibo-forms.js	2016-09-01 07:41:43 +0000
@@ -514,9 +514,11 @@
 function permissionsFormSubmit(id) {
 
     var form = $("#" + id);
+    var $formContainer = form.closest(".permissions-form");
     var permissions = {
         "groupIds": $(form).data().permissions,
-        "cascade": $("#cascade").is(":checked")
+        "ownerId": $formContainer.find("select[name=ownerId]").val(),
+        "cascade": $formContainer.find("#cascade").is(":checked")
     };
     var data = $.param(permissions);
 

